@@ -1,5 +1,7 @@
 """
-Main interface for lambda service type definitions.
+Type annotations for lambda service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -13,6 +15,20 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
+from .literals import (
+    CodeSigningPolicyType,
+    EventSourcePositionType,
+    LastUpdateStatusReasonCodeType,
+    LastUpdateStatusType,
+    PackageTypeType,
+    ProvisionedConcurrencyStatusEnumType,
+    RuntimeType,
+    SourceAccessTypeType,
+    StateReasonCodeType,
+    StateType,
+    TracingModeType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
@@ -26,41 +42,26 @@ else:
 __all__ = (
     "AccountLimitTypeDef",
     "AccountUsageTypeDef",
+    "AddLayerVersionPermissionResponseTypeDef",
+    "AddPermissionResponseTypeDef",
     "AliasConfigurationTypeDef",
     "AliasRoutingConfigurationTypeDef",
     "AllowedPublishersTypeDef",
     "CodeSigningConfigTypeDef",
     "CodeSigningPoliciesTypeDef",
     "ConcurrencyTypeDef",
+    "CreateCodeSigningConfigResponseTypeDef",
     "DeadLetterConfigTypeDef",
     "DestinationConfigTypeDef",
     "EnvironmentErrorTypeDef",
     "EnvironmentResponseTypeDef",
+    "EnvironmentTypeDef",
     "EventSourceMappingConfigurationTypeDef",
     "FileSystemConfigTypeDef",
     "FunctionCodeLocationTypeDef",
+    "FunctionCodeTypeDef",
     "FunctionConfigurationTypeDef",
     "FunctionEventInvokeConfigTypeDef",
-    "ImageConfigErrorTypeDef",
-    "ImageConfigResponseTypeDef",
-    "ImageConfigTypeDef",
-    "LayerTypeDef",
-    "LayerVersionContentOutputTypeDef",
-    "LayerVersionsListItemTypeDef",
-    "LayersListItemTypeDef",
-    "OnFailureTypeDef",
-    "OnSuccessTypeDef",
-    "ProvisionedConcurrencyConfigListItemTypeDef",
-    "ResponseMetadata",
-    "SelfManagedEventSourceTypeDef",
-    "SourceAccessConfigurationTypeDef",
-    "TracingConfigResponseTypeDef",
-    "VpcConfigResponseTypeDef",
-    "AddLayerVersionPermissionResponseTypeDef",
-    "AddPermissionResponseTypeDef",
-    "CreateCodeSigningConfigResponseTypeDef",
-    "EnvironmentTypeDef",
-    "FunctionCodeTypeDef",
     "GetAccountSettingsResponseTypeDef",
     "GetCodeSigningConfigResponseTypeDef",
     "GetFunctionCodeSigningConfigResponseTypeDef",
@@ -70,9 +71,16 @@ __all__ = (
     "GetLayerVersionResponseTypeDef",
     "GetPolicyResponseTypeDef",
     "GetProvisionedConcurrencyConfigResponseTypeDef",
+    "ImageConfigErrorTypeDef",
+    "ImageConfigResponseTypeDef",
+    "ImageConfigTypeDef",
     "InvocationResponseTypeDef",
     "InvokeAsyncResponseTypeDef",
+    "LayerTypeDef",
     "LayerVersionContentInputTypeDef",
+    "LayerVersionContentOutputTypeDef",
+    "LayerVersionsListItemTypeDef",
+    "LayersListItemTypeDef",
     "ListAliasesResponseTypeDef",
     "ListCodeSigningConfigsResponseTypeDef",
     "ListEventSourceMappingsResponseTypeDef",
@@ -84,12 +92,20 @@ __all__ = (
     "ListProvisionedConcurrencyConfigsResponseTypeDef",
     "ListTagsResponseTypeDef",
     "ListVersionsByFunctionResponseTypeDef",
+    "OnFailureTypeDef",
+    "OnSuccessTypeDef",
     "PaginatorConfigTypeDef",
+    "ProvisionedConcurrencyConfigListItemTypeDef",
     "PublishLayerVersionResponseTypeDef",
     "PutFunctionCodeSigningConfigResponseTypeDef",
     "PutProvisionedConcurrencyConfigResponseTypeDef",
+    "ResponseMetadataTypeDef",
+    "SelfManagedEventSourceTypeDef",
+    "SourceAccessConfigurationTypeDef",
+    "TracingConfigResponseTypeDef",
     "TracingConfigTypeDef",
     "UpdateCodeSigningConfigResponseTypeDef",
+    "VpcConfigResponseTypeDef",
     "VpcConfigTypeDef",
     "WaiterConfigTypeDef",
 )
@@ -107,7 +123,29 @@ AccountLimitTypeDef = TypedDict(
 )
 
 AccountUsageTypeDef = TypedDict(
-    "AccountUsageTypeDef", {"TotalCodeSize": int, "FunctionCount": int}, total=False
+    "AccountUsageTypeDef",
+    {
+        "TotalCodeSize": int,
+        "FunctionCount": int,
+    },
+    total=False,
+)
+
+AddLayerVersionPermissionResponseTypeDef = TypedDict(
+    "AddLayerVersionPermissionResponseTypeDef",
+    {
+        "Statement": str,
+        "RevisionId": str,
+    },
+    total=False,
+)
+
+AddPermissionResponseTypeDef = TypedDict(
+    "AddPermissionResponseTypeDef",
+    {
+        "Statement": str,
+    },
+    total=False,
 )
 
 AliasConfigurationTypeDef = TypedDict(
@@ -124,11 +162,18 @@ AliasConfigurationTypeDef = TypedDict(
 )
 
 AliasRoutingConfigurationTypeDef = TypedDict(
-    "AliasRoutingConfigurationTypeDef", {"AdditionalVersionWeights": Dict[str, float]}, total=False
+    "AliasRoutingConfigurationTypeDef",
+    {
+        "AdditionalVersionWeights": Dict[str, float],
+    },
+    total=False,
 )
 
 AllowedPublishersTypeDef = TypedDict(
-    "AllowedPublishersTypeDef", {"SigningProfileVersionArns": List[str]}
+    "AllowedPublishersTypeDef",
+    {
+        "SigningProfileVersionArns": List[str],
+    },
 )
 
 _RequiredCodeSigningConfigTypeDef = TypedDict(
@@ -142,7 +187,11 @@ _RequiredCodeSigningConfigTypeDef = TypedDict(
     },
 )
 _OptionalCodeSigningConfigTypeDef = TypedDict(
-    "_OptionalCodeSigningConfigTypeDef", {"Description": str}, total=False
+    "_OptionalCodeSigningConfigTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
 )
 
 
@@ -154,29 +203,67 @@ class CodeSigningConfigTypeDef(
 
 CodeSigningPoliciesTypeDef = TypedDict(
     "CodeSigningPoliciesTypeDef",
-    {"UntrustedArtifactOnDeployment": Literal["Warn", "Enforce"]},
+    {
+        "UntrustedArtifactOnDeployment": CodeSigningPolicyType,
+    },
     total=False,
 )
 
 ConcurrencyTypeDef = TypedDict(
-    "ConcurrencyTypeDef", {"ReservedConcurrentExecutions": int}, total=False
+    "ConcurrencyTypeDef",
+    {
+        "ReservedConcurrentExecutions": int,
+    },
+    total=False,
 )
 
-DeadLetterConfigTypeDef = TypedDict("DeadLetterConfigTypeDef", {"TargetArn": str}, total=False)
+CreateCodeSigningConfigResponseTypeDef = TypedDict(
+    "CreateCodeSigningConfigResponseTypeDef",
+    {
+        "CodeSigningConfig": "CodeSigningConfigTypeDef",
+    },
+)
+
+DeadLetterConfigTypeDef = TypedDict(
+    "DeadLetterConfigTypeDef",
+    {
+        "TargetArn": str,
+    },
+    total=False,
+)
 
 DestinationConfigTypeDef = TypedDict(
     "DestinationConfigTypeDef",
-    {"OnSuccess": "OnSuccessTypeDef", "OnFailure": "OnFailureTypeDef"},
+    {
+        "OnSuccess": "OnSuccessTypeDef",
+        "OnFailure": "OnFailureTypeDef",
+    },
     total=False,
 )
 
 EnvironmentErrorTypeDef = TypedDict(
-    "EnvironmentErrorTypeDef", {"ErrorCode": str, "Message": str}, total=False
+    "EnvironmentErrorTypeDef",
+    {
+        "ErrorCode": str,
+        "Message": str,
+    },
+    total=False,
 )
 
 EnvironmentResponseTypeDef = TypedDict(
     "EnvironmentResponseTypeDef",
-    {"Variables": Dict[str, str], "Error": "EnvironmentErrorTypeDef"},
+    {
+        "Variables": Dict[str, str],
+        "Error": "EnvironmentErrorTypeDef",
+    },
+    total=False,
+)
+
+EnvironmentTypeDef = TypedDict(
+    "EnvironmentTypeDef",
+    {
+        "Variables": Dict[str, str],
+    },
     total=False,
 )
 
@@ -184,7 +271,7 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
     "EventSourceMappingConfigurationTypeDef",
     {
         "UUID": str,
-        "StartingPosition": Literal["TRIM_HORIZON", "LATEST", "AT_TIMESTAMP"],
+        "StartingPosition": EventSourcePositionType,
         "StartingPositionTimestamp": datetime,
         "BatchSize": int,
         "MaximumBatchingWindowInSeconds": int,
@@ -209,11 +296,34 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-FileSystemConfigTypeDef = TypedDict("FileSystemConfigTypeDef", {"Arn": str, "LocalMountPath": str})
+FileSystemConfigTypeDef = TypedDict(
+    "FileSystemConfigTypeDef",
+    {
+        "Arn": str,
+        "LocalMountPath": str,
+    },
+)
 
 FunctionCodeLocationTypeDef = TypedDict(
     "FunctionCodeLocationTypeDef",
-    {"RepositoryType": str, "Location": str, "ImageUri": str, "ResolvedImageUri": str},
+    {
+        "RepositoryType": str,
+        "Location": str,
+        "ImageUri": str,
+        "ResolvedImageUri": str,
+    },
+    total=False,
+)
+
+FunctionCodeTypeDef = TypedDict(
+    "FunctionCodeTypeDef",
+    {
+        "ZipFile": Union[bytes, IO[bytes]],
+        "S3Bucket": str,
+        "S3Key": str,
+        "S3ObjectVersion": str,
+        "ImageUri": str,
+    },
     total=False,
 )
 
@@ -222,32 +332,7 @@ FunctionConfigurationTypeDef = TypedDict(
     {
         "FunctionName": str,
         "FunctionArn": str,
-        "Runtime": Literal[
-            "nodejs",
-            "nodejs4.3",
-            "nodejs6.10",
-            "nodejs8.10",
-            "nodejs10.x",
-            "nodejs12.x",
-            "nodejs14.x",
-            "java8",
-            "java8.al2",
-            "java11",
-            "python2.7",
-            "python3.6",
-            "python3.7",
-            "python3.8",
-            "dotnetcore1.0",
-            "dotnetcore2.0",
-            "dotnetcore2.1",
-            "dotnetcore3.1",
-            "nodejs4.3-edge",
-            "go1.x",
-            "ruby2.5",
-            "ruby2.7",
-            "provided",
-            "provided.al2",
-        ],
+        "Runtime": RuntimeType,
         "Role": str,
         "Handler": str,
         "CodeSize": int,
@@ -265,39 +350,14 @@ FunctionConfigurationTypeDef = TypedDict(
         "MasterArn": str,
         "RevisionId": str,
         "Layers": List["LayerTypeDef"],
-        "State": Literal["Pending", "Active", "Inactive", "Failed"],
+        "State": StateType,
         "StateReason": str,
-        "StateReasonCode": Literal[
-            "Idle",
-            "Creating",
-            "Restoring",
-            "EniLimitExceeded",
-            "InsufficientRolePermissions",
-            "InvalidConfiguration",
-            "InternalError",
-            "SubnetOutOfIPAddresses",
-            "InvalidSubnet",
-            "InvalidSecurityGroup",
-            "ImageDeleted",
-            "ImageAccessDenied",
-            "InvalidImage",
-        ],
-        "LastUpdateStatus": Literal["Successful", "Failed", "InProgress"],
+        "StateReasonCode": StateReasonCodeType,
+        "LastUpdateStatus": LastUpdateStatusType,
         "LastUpdateStatusReason": str,
-        "LastUpdateStatusReasonCode": Literal[
-            "EniLimitExceeded",
-            "InsufficientRolePermissions",
-            "InvalidConfiguration",
-            "InternalError",
-            "SubnetOutOfIPAddresses",
-            "InvalidSubnet",
-            "InvalidSecurityGroup",
-            "ImageDeleted",
-            "ImageAccessDenied",
-            "InvalidImage",
-        ],
+        "LastUpdateStatusReasonCode": LastUpdateStatusReasonCodeType,
         "FileSystemConfigs": List["FileSystemConfigTypeDef"],
-        "PackageType": Literal["Zip", "Image"],
+        "PackageType": PackageTypeType,
         "ImageConfigResponse": "ImageConfigResponseTypeDef",
         "SigningProfileVersionArn": str,
         "SigningJobArn": str,
@@ -317,190 +377,36 @@ FunctionEventInvokeConfigTypeDef = TypedDict(
     total=False,
 )
 
-ImageConfigErrorTypeDef = TypedDict(
-    "ImageConfigErrorTypeDef", {"ErrorCode": str, "Message": str}, total=False
-)
-
-ImageConfigResponseTypeDef = TypedDict(
-    "ImageConfigResponseTypeDef",
-    {"ImageConfig": "ImageConfigTypeDef", "Error": "ImageConfigErrorTypeDef"},
-    total=False,
-)
-
-ImageConfigTypeDef = TypedDict(
-    "ImageConfigTypeDef",
-    {"EntryPoint": List[str], "Command": List[str], "WorkingDirectory": str},
-    total=False,
-)
-
-LayerTypeDef = TypedDict(
-    "LayerTypeDef",
-    {"Arn": str, "CodeSize": int, "SigningProfileVersionArn": str, "SigningJobArn": str},
-    total=False,
-)
-
-LayerVersionContentOutputTypeDef = TypedDict(
-    "LayerVersionContentOutputTypeDef",
-    {
-        "Location": str,
-        "CodeSha256": str,
-        "CodeSize": int,
-        "SigningProfileVersionArn": str,
-        "SigningJobArn": str,
-        "ResponseMetadata": "ResponseMetadata",
-    },
-    total=False,
-)
-
-LayerVersionsListItemTypeDef = TypedDict(
-    "LayerVersionsListItemTypeDef",
-    {
-        "LayerVersionArn": str,
-        "Version": int,
-        "Description": str,
-        "CreatedDate": str,
-        "CompatibleRuntimes": List[
-            Literal[
-                "nodejs",
-                "nodejs4.3",
-                "nodejs6.10",
-                "nodejs8.10",
-                "nodejs10.x",
-                "nodejs12.x",
-                "nodejs14.x",
-                "java8",
-                "java8.al2",
-                "java11",
-                "python2.7",
-                "python3.6",
-                "python3.7",
-                "python3.8",
-                "dotnetcore1.0",
-                "dotnetcore2.0",
-                "dotnetcore2.1",
-                "dotnetcore3.1",
-                "nodejs4.3-edge",
-                "go1.x",
-                "ruby2.5",
-                "ruby2.7",
-                "provided",
-                "provided.al2",
-            ]
-        ],
-        "LicenseInfo": str,
-    },
-    total=False,
-)
-
-LayersListItemTypeDef = TypedDict(
-    "LayersListItemTypeDef",
-    {"LayerName": str, "LayerArn": str, "LatestMatchingVersion": "LayerVersionsListItemTypeDef"},
-    total=False,
-)
-
-OnFailureTypeDef = TypedDict("OnFailureTypeDef", {"Destination": str}, total=False)
-
-OnSuccessTypeDef = TypedDict("OnSuccessTypeDef", {"Destination": str}, total=False)
-
-ProvisionedConcurrencyConfigListItemTypeDef = TypedDict(
-    "ProvisionedConcurrencyConfigListItemTypeDef",
-    {
-        "FunctionArn": str,
-        "RequestedProvisionedConcurrentExecutions": int,
-        "AvailableProvisionedConcurrentExecutions": int,
-        "AllocatedProvisionedConcurrentExecutions": int,
-        "Status": Literal["IN_PROGRESS", "READY", "FAILED"],
-        "StatusReason": str,
-        "LastModified": str,
-    },
-    total=False,
-)
-
-ResponseMetadata = TypedDict(
-    "ResponseMetadata",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
-        "RetryAttempts": int,
-    },
-)
-
-SelfManagedEventSourceTypeDef = TypedDict(
-    "SelfManagedEventSourceTypeDef",
-    {"Endpoints": Dict[Literal["KAFKA_BOOTSTRAP_SERVERS"], List[str]]},
-    total=False,
-)
-
-SourceAccessConfigurationTypeDef = TypedDict(
-    "SourceAccessConfigurationTypeDef",
-    {
-        "Type": Literal[
-            "BASIC_AUTH",
-            "VPC_SUBNET",
-            "VPC_SECURITY_GROUP",
-            "SASL_SCRAM_512_AUTH",
-            "SASL_SCRAM_256_AUTH",
-        ],
-        "URI": str,
-    },
-    total=False,
-)
-
-TracingConfigResponseTypeDef = TypedDict(
-    "TracingConfigResponseTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
-)
-
-VpcConfigResponseTypeDef = TypedDict(
-    "VpcConfigResponseTypeDef",
-    {"SubnetIds": List[str], "SecurityGroupIds": List[str], "VpcId": str},
-    total=False,
-)
-
-AddLayerVersionPermissionResponseTypeDef = TypedDict(
-    "AddLayerVersionPermissionResponseTypeDef", {"Statement": str, "RevisionId": str}, total=False
-)
-
-AddPermissionResponseTypeDef = TypedDict(
-    "AddPermissionResponseTypeDef", {"Statement": str}, total=False
-)
-
-CreateCodeSigningConfigResponseTypeDef = TypedDict(
-    "CreateCodeSigningConfigResponseTypeDef", {"CodeSigningConfig": "CodeSigningConfigTypeDef"}
-)
-
-EnvironmentTypeDef = TypedDict("EnvironmentTypeDef", {"Variables": Dict[str, str]}, total=False)
-
-FunctionCodeTypeDef = TypedDict(
-    "FunctionCodeTypeDef",
-    {
-        "ZipFile": Union[bytes, IO[bytes]],
-        "S3Bucket": str,
-        "S3Key": str,
-        "S3ObjectVersion": str,
-        "ImageUri": str,
-    },
-    total=False,
-)
-
 GetAccountSettingsResponseTypeDef = TypedDict(
     "GetAccountSettingsResponseTypeDef",
-    {"AccountLimit": "AccountLimitTypeDef", "AccountUsage": "AccountUsageTypeDef"},
+    {
+        "AccountLimit": "AccountLimitTypeDef",
+        "AccountUsage": "AccountUsageTypeDef",
+    },
     total=False,
 )
 
 GetCodeSigningConfigResponseTypeDef = TypedDict(
-    "GetCodeSigningConfigResponseTypeDef", {"CodeSigningConfig": "CodeSigningConfigTypeDef"}
+    "GetCodeSigningConfigResponseTypeDef",
+    {
+        "CodeSigningConfig": "CodeSigningConfigTypeDef",
+    },
 )
 
 GetFunctionCodeSigningConfigResponseTypeDef = TypedDict(
     "GetFunctionCodeSigningConfigResponseTypeDef",
-    {"CodeSigningConfigArn": str, "FunctionName": str},
+    {
+        "CodeSigningConfigArn": str,
+        "FunctionName": str,
+    },
 )
 
 GetFunctionConcurrencyResponseTypeDef = TypedDict(
-    "GetFunctionConcurrencyResponseTypeDef", {"ReservedConcurrentExecutions": int}, total=False
+    "GetFunctionConcurrencyResponseTypeDef",
+    {
+        "ReservedConcurrentExecutions": int,
+    },
+    total=False,
 )
 
 GetFunctionResponseTypeDef = TypedDict(
@@ -515,7 +421,12 @@ GetFunctionResponseTypeDef = TypedDict(
 )
 
 GetLayerVersionPolicyResponseTypeDef = TypedDict(
-    "GetLayerVersionPolicyResponseTypeDef", {"Policy": str, "RevisionId": str}, total=False
+    "GetLayerVersionPolicyResponseTypeDef",
+    {
+        "Policy": str,
+        "RevisionId": str,
+    },
+    total=False,
 )
 
 GetLayerVersionResponseTypeDef = TypedDict(
@@ -527,41 +438,19 @@ GetLayerVersionResponseTypeDef = TypedDict(
         "Description": str,
         "CreatedDate": str,
         "Version": int,
-        "CompatibleRuntimes": List[
-            Literal[
-                "nodejs",
-                "nodejs4.3",
-                "nodejs6.10",
-                "nodejs8.10",
-                "nodejs10.x",
-                "nodejs12.x",
-                "nodejs14.x",
-                "java8",
-                "java8.al2",
-                "java11",
-                "python2.7",
-                "python3.6",
-                "python3.7",
-                "python3.8",
-                "dotnetcore1.0",
-                "dotnetcore2.0",
-                "dotnetcore2.1",
-                "dotnetcore3.1",
-                "nodejs4.3-edge",
-                "go1.x",
-                "ruby2.5",
-                "ruby2.7",
-                "provided",
-                "provided.al2",
-            ]
-        ],
+        "CompatibleRuntimes": List[RuntimeType],
         "LicenseInfo": str,
     },
     total=False,
 )
 
 GetPolicyResponseTypeDef = TypedDict(
-    "GetPolicyResponseTypeDef", {"Policy": str, "RevisionId": str}, total=False
+    "GetPolicyResponseTypeDef",
+    {
+        "Policy": str,
+        "RevisionId": str,
+    },
+    total=False,
 )
 
 GetProvisionedConcurrencyConfigResponseTypeDef = TypedDict(
@@ -570,13 +459,41 @@ GetProvisionedConcurrencyConfigResponseTypeDef = TypedDict(
         "RequestedProvisionedConcurrentExecutions": int,
         "AvailableProvisionedConcurrentExecutions": int,
         "AllocatedProvisionedConcurrentExecutions": int,
-        "Status": Literal["IN_PROGRESS", "READY", "FAILED"],
+        "Status": ProvisionedConcurrencyStatusEnumType,
         "StatusReason": str,
         "LastModified": str,
     },
     total=False,
 )
 
+ImageConfigErrorTypeDef = TypedDict(
+    "ImageConfigErrorTypeDef",
+    {
+        "ErrorCode": str,
+        "Message": str,
+    },
+    total=False,
+)
+
+ImageConfigResponseTypeDef = TypedDict(
+    "ImageConfigResponseTypeDef",
+    {
+        "ImageConfig": "ImageConfigTypeDef",
+        "Error": "ImageConfigErrorTypeDef",
+    },
+    total=False,
+)
+
+ImageConfigTypeDef = TypedDict(
+    "ImageConfigTypeDef",
+    {
+        "EntryPoint": List[str],
+        "Command": List[str],
+        "WorkingDirectory": str,
+    },
+    total=False,
+)
+
 InvocationResponseTypeDef = TypedDict(
     "InvocationResponseTypeDef",
     {
@@ -589,59 +506,140 @@ InvocationResponseTypeDef = TypedDict(
     total=False,
 )
 
-InvokeAsyncResponseTypeDef = TypedDict("InvokeAsyncResponseTypeDef", {"Status": int}, total=False)
+InvokeAsyncResponseTypeDef = TypedDict(
+    "InvokeAsyncResponseTypeDef",
+    {
+        "Status": int,
+    },
+    total=False,
+)
+
+LayerTypeDef = TypedDict(
+    "LayerTypeDef",
+    {
+        "Arn": str,
+        "CodeSize": int,
+        "SigningProfileVersionArn": str,
+        "SigningJobArn": str,
+    },
+    total=False,
+)
 
 LayerVersionContentInputTypeDef = TypedDict(
     "LayerVersionContentInputTypeDef",
-    {"S3Bucket": str, "S3Key": str, "S3ObjectVersion": str, "ZipFile": Union[bytes, IO[bytes]]},
+    {
+        "S3Bucket": str,
+        "S3Key": str,
+        "S3ObjectVersion": str,
+        "ZipFile": Union[bytes, IO[bytes]],
+    },
+    total=False,
+)
+
+LayerVersionContentOutputTypeDef = TypedDict(
+    "LayerVersionContentOutputTypeDef",
+    {
+        "Location": str,
+        "CodeSha256": str,
+        "CodeSize": int,
+        "SigningProfileVersionArn": str,
+        "SigningJobArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+LayerVersionsListItemTypeDef = TypedDict(
+    "LayerVersionsListItemTypeDef",
+    {
+        "LayerVersionArn": str,
+        "Version": int,
+        "Description": str,
+        "CreatedDate": str,
+        "CompatibleRuntimes": List[RuntimeType],
+        "LicenseInfo": str,
+    },
+    total=False,
+)
+
+LayersListItemTypeDef = TypedDict(
+    "LayersListItemTypeDef",
+    {
+        "LayerName": str,
+        "LayerArn": str,
+        "LatestMatchingVersion": "LayerVersionsListItemTypeDef",
+    },
     total=False,
 )
 
 ListAliasesResponseTypeDef = TypedDict(
     "ListAliasesResponseTypeDef",
-    {"NextMarker": str, "Aliases": List["AliasConfigurationTypeDef"]},
+    {
+        "NextMarker": str,
+        "Aliases": List["AliasConfigurationTypeDef"],
+    },
     total=False,
 )
 
 ListCodeSigningConfigsResponseTypeDef = TypedDict(
     "ListCodeSigningConfigsResponseTypeDef",
-    {"NextMarker": str, "CodeSigningConfigs": List["CodeSigningConfigTypeDef"]},
+    {
+        "NextMarker": str,
+        "CodeSigningConfigs": List["CodeSigningConfigTypeDef"],
+    },
     total=False,
 )
 
 ListEventSourceMappingsResponseTypeDef = TypedDict(
     "ListEventSourceMappingsResponseTypeDef",
-    {"NextMarker": str, "EventSourceMappings": List["EventSourceMappingConfigurationTypeDef"]},
+    {
+        "NextMarker": str,
+        "EventSourceMappings": List["EventSourceMappingConfigurationTypeDef"],
+    },
     total=False,
 )
 
 ListFunctionEventInvokeConfigsResponseTypeDef = TypedDict(
     "ListFunctionEventInvokeConfigsResponseTypeDef",
-    {"FunctionEventInvokeConfigs": List["FunctionEventInvokeConfigTypeDef"], "NextMarker": str},
+    {
+        "FunctionEventInvokeConfigs": List["FunctionEventInvokeConfigTypeDef"],
+        "NextMarker": str,
+    },
     total=False,
 )
 
 ListFunctionsByCodeSigningConfigResponseTypeDef = TypedDict(
     "ListFunctionsByCodeSigningConfigResponseTypeDef",
-    {"NextMarker": str, "FunctionArns": List[str]},
+    {
+        "NextMarker": str,
+        "FunctionArns": List[str],
+    },
     total=False,
 )
 
 ListFunctionsResponseTypeDef = TypedDict(
     "ListFunctionsResponseTypeDef",
-    {"NextMarker": str, "Functions": List["FunctionConfigurationTypeDef"]},
+    {
+        "NextMarker": str,
+        "Functions": List["FunctionConfigurationTypeDef"],
+    },
     total=False,
 )
 
 ListLayerVersionsResponseTypeDef = TypedDict(
     "ListLayerVersionsResponseTypeDef",
-    {"NextMarker": str, "LayerVersions": List["LayerVersionsListItemTypeDef"]},
+    {
+        "NextMarker": str,
+        "LayerVersions": List["LayerVersionsListItemTypeDef"],
+    },
     total=False,
 )
 
 ListLayersResponseTypeDef = TypedDict(
     "ListLayersResponseTypeDef",
-    {"NextMarker": str, "Layers": List["LayersListItemTypeDef"]},
+    {
+        "NextMarker": str,
+        "Layers": List["LayersListItemTypeDef"],
+    },
     total=False,
 )
 
@@ -655,17 +653,60 @@ ListProvisionedConcurrencyConfigsResponseTypeDef = TypedDict(
 )
 
 ListTagsResponseTypeDef = TypedDict(
-    "ListTagsResponseTypeDef", {"Tags": Dict[str, str]}, total=False
+    "ListTagsResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
 )
 
 ListVersionsByFunctionResponseTypeDef = TypedDict(
     "ListVersionsByFunctionResponseTypeDef",
-    {"NextMarker": str, "Versions": List["FunctionConfigurationTypeDef"]},
+    {
+        "NextMarker": str,
+        "Versions": List["FunctionConfigurationTypeDef"],
+    },
+    total=False,
+)
+
+OnFailureTypeDef = TypedDict(
+    "OnFailureTypeDef",
+    {
+        "Destination": str,
+    },
+    total=False,
+)
+
+OnSuccessTypeDef = TypedDict(
+    "OnSuccessTypeDef",
+    {
+        "Destination": str,
+    },
     total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+ProvisionedConcurrencyConfigListItemTypeDef = TypedDict(
+    "ProvisionedConcurrencyConfigListItemTypeDef",
+    {
+        "FunctionArn": str,
+        "RequestedProvisionedConcurrentExecutions": int,
+        "AvailableProvisionedConcurrentExecutions": int,
+        "AllocatedProvisionedConcurrentExecutions": int,
+        "Status": ProvisionedConcurrencyStatusEnumType,
+        "StatusReason": str,
+        "LastModified": str,
+    },
+    total=False,
 )
 
 PublishLayerVersionResponseTypeDef = TypedDict(
@@ -677,34 +718,7 @@ PublishLayerVersionResponseTypeDef = TypedDict(
         "Description": str,
         "CreatedDate": str,
         "Version": int,
-        "CompatibleRuntimes": List[
-            Literal[
-                "nodejs",
-                "nodejs4.3",
-                "nodejs6.10",
-                "nodejs8.10",
-                "nodejs10.x",
-                "nodejs12.x",
-                "nodejs14.x",
-                "java8",
-                "java8.al2",
-                "java11",
-                "python2.7",
-                "python3.6",
-                "python3.7",
-                "python3.8",
-                "dotnetcore1.0",
-                "dotnetcore2.0",
-                "dotnetcore2.1",
-                "dotnetcore3.1",
-                "nodejs4.3-edge",
-                "go1.x",
-                "ruby2.5",
-                "ruby2.7",
-                "provided",
-                "provided.al2",
-            ]
-        ],
+        "CompatibleRuntimes": List[RuntimeType],
         "LicenseInfo": str,
     },
     total=False,
@@ -712,7 +726,10 @@ PublishLayerVersionResponseTypeDef = TypedDict(
 
 PutFunctionCodeSigningConfigResponseTypeDef = TypedDict(
     "PutFunctionCodeSigningConfigResponseTypeDef",
-    {"CodeSigningConfigArn": str, "FunctionName": str},
+    {
+        "CodeSigningConfigArn": str,
+        "FunctionName": str,
+    },
 )
 
 PutProvisionedConcurrencyConfigResponseTypeDef = TypedDict(
@@ -721,25 +738,88 @@ PutProvisionedConcurrencyConfigResponseTypeDef = TypedDict(
         "RequestedProvisionedConcurrentExecutions": int,
         "AvailableProvisionedConcurrentExecutions": int,
         "AllocatedProvisionedConcurrentExecutions": int,
-        "Status": Literal["IN_PROGRESS", "READY", "FAILED"],
+        "Status": ProvisionedConcurrencyStatusEnumType,
         "StatusReason": str,
         "LastModified": str,
     },
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+SelfManagedEventSourceTypeDef = TypedDict(
+    "SelfManagedEventSourceTypeDef",
+    {
+        "Endpoints": Dict[Literal["KAFKA_BOOTSTRAP_SERVERS"], List[str]],
+    },
+    total=False,
+)
+
+SourceAccessConfigurationTypeDef = TypedDict(
+    "SourceAccessConfigurationTypeDef",
+    {
+        "Type": SourceAccessTypeType,
+        "URI": str,
+    },
+    total=False,
+)
+
+TracingConfigResponseTypeDef = TypedDict(
+    "TracingConfigResponseTypeDef",
+    {
+        "Mode": TracingModeType,
+    },
+    total=False,
+)
+
 TracingConfigTypeDef = TypedDict(
-    "TracingConfigTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
+    "TracingConfigTypeDef",
+    {
+        "Mode": TracingModeType,
+    },
+    total=False,
 )
 
 UpdateCodeSigningConfigResponseTypeDef = TypedDict(
-    "UpdateCodeSigningConfigResponseTypeDef", {"CodeSigningConfig": "CodeSigningConfigTypeDef"}
+    "UpdateCodeSigningConfigResponseTypeDef",
+    {
+        "CodeSigningConfig": "CodeSigningConfigTypeDef",
+    },
+)
+
+VpcConfigResponseTypeDef = TypedDict(
+    "VpcConfigResponseTypeDef",
+    {
+        "SubnetIds": List[str],
+        "SecurityGroupIds": List[str],
+        "VpcId": str,
+    },
+    total=False,
 )
 
 VpcConfigTypeDef = TypedDict(
-    "VpcConfigTypeDef", {"SubnetIds": List[str], "SecurityGroupIds": List[str]}, total=False
+    "VpcConfigTypeDef",
+    {
+        "SubnetIds": List[str],
+        "SecurityGroupIds": List[str],
+    },
+    total=False,
 )
 
 WaiterConfigTypeDef = TypedDict(
-    "WaiterConfigTypeDef", {"Delay": int, "MaxAttempts": int}, total=False
+    "WaiterConfigTypeDef",
+    {
+        "Delay": int,
+        "MaxAttempts": int,
+    },
+    total=False,
 )
